@@ -15,12 +15,13 @@ gbm <- function(npaths, timesteps, r, v, tau, S0) {
         ans <- ans + s0
     exp(ans)
 }
+
 gbb <- function(npaths, timesteps, S0, ST, v, tau) {
         gbm <- t(gbm(npaths, timesteps, 0, v, tau, S0 = S0))[ ,-1L]
     w <- seq_len(timesteps)/timesteps
     ans <- gbm - as.matrix((gbm[,timesteps]-S0)) %*% w
     rbind(S0, t(ans + as.matrix(rep(ST - S0, npaths)) %*% w), deparse.level=0)
 }
-mc <- function(paths, payoff, ...) {
+
+mc <- function(paths, payoff, ...) 
     payoff(paths, ...) 
-}
