@@ -1,8 +1,13 @@
 ## -*- truncate-lines: t; -*-
-## Time-stamp: <2014-01-06 16:13:59 CET (es)>
-
 ## create random portfolios
 
+## n .. number of assets available
+## k .. number of assets in solution
+## sum_w .. sum of weights (typically 1)
+## abssum_w .. sum of absolute weights (useful for long/short portfolios)
+## wmin ..
+## wmax ..
+
 long.only <- function(n, budget = 1) {
     ans <- runif(n)
     budget * ans/sum(ans)
@@ -23,8 +28,3 @@ long.short <- function(n, budget = 1) {
     }
     budget*ans/sum(ans)
 }
-
-random.p <- function(n, budget = 1,
-                     wmin = 0, wmax = Inf, abs.max = Inf) {
-
-}
